# Changelog

All notable changes to this project will be documented in this file.

## [0.0.2] - 2025-01-14

### Added

- Foundational code for django_orgs.
- changelog


[0.0.2]: https://github.com/jmitchel3/django-orgs/compare/v0.0.2...HEAD
